@@ -46,12 +46,11 @@ def generate_oidc_cookies(session, response):
     """
     # This script only works if we save the access token in session
     if settings.OIDC_STORE_ACCESS_TOKEN:
-        print(session.get('oidc_states'))
         oidc_id_token_expiration = session.get('oidc_id_token_expiration', None)
         oidc_access_token = session.get('oidc_access_token', None)
         oidc_id_token = session.get('oidc_id_token', None)
         oidc_states = session.get('oidc_states', {})
-        oidc_login_next = None
+        oidc_login_next = ''
 
         # We need these tree variables to login, if at least one is None or empty, then return
         if not all([oidc_id_token_expiration, oidc_access_token, oidc_id_token]):
